@@ -67,7 +67,7 @@ impl Session {
         }
     }
 
-    async fn retrieve_contract(&mut self, link: &InitialLink) -> Result<(String, BTreeSet<String>), String> {
+    async fn retrieve_contract(&mut self, link: &InitialLink) -> Result<(String, BTreeSet<QualifiedContractIdentifier>), String> {
         let contract_id = &link.contract_id;
         let components: Vec<&str> = contract_id.split('.').collect();
         let contract_deployer = components.first().expect("");
@@ -123,10 +123,10 @@ impl Session {
             };
 
             if deps.len() > 0 {
-                dependencies.insert(contract_id.to_string(), deps.clone().into_iter().collect());
+                dependencies.insert(contract_id.to_string(), deps.clone().into_iter().map(|c| format!("{}", c)).collect());
                 for contract_id in deps.into_iter() {
                     queue.push_back(InitialLink {
-                        contract_id,
+                        contract_id: contract_id.to_string(),
                         cache: initial_link.cache.clone(),
                         stacks_node_addr: initial_link.stacks_node_addr.clone(),
                     });
